==> camel-k-model-v1-6.0.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformKameletSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationPlatformKameletSpecFluent<A extends IntegrationPlatformKameletSpecFluent<A>> extends Fluent<A>{
  public A addToRepositories(Integer index,IntegrationPlatformKameletRepositorySpec item);
  public A setToRepositories(Integer index,IntegrationPlatformKameletRepositorySpec item);
  public A addToRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... items);
  public A addAllToRepositories(Collection<IntegrationPlatformKameletRepositorySpec> items);
  public A removeFromRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... items);
  public A removeAllFromRepositories(Collection<IntegrationPlatformKameletRepositorySpec> items);
  public A removeMatchingFromRepositories(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRepositories instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationPlatformKameletRepositorySpec> getRepositories();
  public List<IntegrationPlatformKameletRepositorySpec> buildRepositories();
  public IntegrationPlatformKameletRepositorySpec buildRepository(Integer index);
  public IntegrationPlatformKameletRepositorySpec buildFirstRepository();
  public IntegrationPlatformKameletRepositorySpec buildLastRepository();
  public IntegrationPlatformKameletRepositorySpec buildMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public Boolean hasMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public A withRepositories(List<IntegrationPlatformKameletRepositorySpec> repositories);
  public A withRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... repositories);
  public Boolean hasRepositories();
  public A addNewRepository(String uri);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> addNewRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> addNewRepositoryLike(IntegrationPlatformKameletRepositorySpec item);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> setNewRepositoryLike(Integer index,IntegrationPlatformKameletRepositorySpec item);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editRepository(Integer index);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editFirstRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editLastRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public interface RepositoriesNested<N> extends Nested<N>,IntegrationPlatformKameletRepositorySpecFluent<IntegrationPlatformKameletSpecFluent.RepositoriesNested<N>>{
    public N and();
    public N endRepository();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformKameletSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationPlatformKameletSpecFluent<A extends IntegrationPlatformKameletSpecFluent<A>> extends Fluent<A>{
  public A addToRepositories(int index,IntegrationPlatformKameletRepositorySpec item);
  public A setToRepositories(int index,IntegrationPlatformKameletRepositorySpec item);
  public A addToRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... items);
  public A addAllToRepositories(Collection<IntegrationPlatformKameletRepositorySpec> items);
  public A removeFromRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... items);
  public A removeAllFromRepositories(Collection<IntegrationPlatformKameletRepositorySpec> items);
  public A removeMatchingFromRepositories(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRepositories instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationPlatformKameletRepositorySpec> getRepositories();
  public List<IntegrationPlatformKameletRepositorySpec> buildRepositories();
  public IntegrationPlatformKameletRepositorySpec buildRepository(int index);
  public IntegrationPlatformKameletRepositorySpec buildFirstRepository();
  public IntegrationPlatformKameletRepositorySpec buildLastRepository();
  public IntegrationPlatformKameletRepositorySpec buildMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public Boolean hasMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public A withRepositories(List<IntegrationPlatformKameletRepositorySpec> repositories);
  public A withRepositories(io.fabric8.camelk.v1.IntegrationPlatformKameletRepositorySpec... repositories);
  public Boolean hasRepositories();
  public A addNewRepository(String uri);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> addNewRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> addNewRepositoryLike(IntegrationPlatformKameletRepositorySpec item);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> setNewRepositoryLike(int index,IntegrationPlatformKameletRepositorySpec item);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editRepository(int index);
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editFirstRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editLastRepository();
  public IntegrationPlatformKameletSpecFluent.RepositoriesNested<A> editMatchingRepository(Predicate<IntegrationPlatformKameletRepositorySpecBuilder> predicate);
  public interface RepositoriesNested<N> extends Nested<N>,IntegrationPlatformKameletRepositorySpecFluent<IntegrationPlatformKameletSpecFluent.RepositoriesNested<N>>{
    public N and();
    public N endRepository();
    
  }
  
}
